require "thor"
require "aws-sdk-core"
require "net/http"

class Arec53::CLI < Thor
  DEFAULT_REGION = "ap-northeast-1"

  class_option :access_key_id,     aliases: [:k]
  class_option :secret_access_key, aliases: [:s]
  class_option :region,            aliases: [:r]
  class_option :profile

  desc "version", "Show arec53 gem version."
  def version
    puts Arec53::VERSION
  end

  desc "update HOSTED_ZONE_ID RECORD_SET_NAME IP_ADDRESS", "Update specified record set with IP address."
  def update hosted_zone_id, record_set_name, ip_address = my_ip, ttl = 300
    begin
      response = client.change_resource_record_sets(
        hosted_zone_id: hosted_zone_id,

        change_batch: {
          changes: [
            {
              action: "UPSERT",

              resource_record_set: {
                name: record_set_name,
                type: "A",
                ttl:  ttl,

                resource_records: [
                  {
                    value: ip_address,
                  },
                ],
              },
            },
          ],
        },
      )

      fail unless response.successful?
      puts "Success"
    rescue => ex
      puts "Failed?"
      p ex
      puts ex.backtrace
    end
  end

  private

  def my_ip
    Net::HTTP.get("checkip.amazonaws.com", "/").chomp
  end

  def client
    @client ||= Aws::Route53::Client.new region: (options[:region] || DEFAULT_REGION)
  end
end
